#ifndef NT2_INCLUDE_CONSTANTS_SQRT_2_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SQRT_2_HPP_INCLUDED

#include <nt2/constant/include/constants/sqrt_2.hpp>

#endif
